#!/usr/bin/python
# -*- coding: utf-8 -*-

# remote cv service
# https://github.com/globocom/thumbor/wiki

# Licensed under the MIT license:
# http://www.opensource.org/licenses/mit-license
# Copyright (c) 2011 globo.com timehome@corp.globo.com

import sys
import argparse
import logging

from redis import Redis
from pyremotecv.unique_queue import UniqueWorker

from remotecv.utils import config

def import_module(name):
    module = __import__(name)
    if '.' in name:
        module = reduce(getattr, name.split('.')[1:], module)
    return module

def main(params=None):
    if params is None:
        params = sys.argv[1:]
    parser = argparse.ArgumentParser(description='Runs RemoteCV.')

    conn_group = parser.add_argument_group('Connection arguments')
    conn_group.add_argument('--host', default='localhost', help='Redis host')
    conn_group.add_argument('--port', default=6379, type=int, help='Redis port')
    conn_group.add_argument('--password', default=None, help='Redis password')

    other_group = parser.add_argument_group('Other arguments')
    other_group.add_argument('-l', '--level', default='debug', help='Logging level')
    other_group.add_argument('-o', '--loader', default='remotecv.http_loader', help='Loader used')

    arguments = parser.parse_args(params)
    logging.basicConfig(level=getattr(logging, arguments.level.upper()))

    config.redis_host = arguments.host
    config.redis_port = arguments.port
    config.loader = import_module(arguments.loader)

    redis = Redis(host=arguments.host, port=arguments.port, password=arguments.password)
    UniqueWorker.run(['Detect'], redis)


if __name__ == "__main__":
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

from remotecv.detectors.face_detector import FaceDetector
from remotecv.detectors.feature_detector import FeatureDetector
from remotecv.detectors.glasses_detector import GlassesDetector
from remotecv.detectors.profile_detector import ProfileDetector
from remotecv.detectors.complete_detector import CompleteDetector
from remotecv.image import Image

class ImageProcessor:
    def __init__(self):
        self.detectors = {
            'all': CompleteDetector(),
            'face': FaceDetector(),
            'feat': FeatureDetector(),
            'glas': GlassesDetector(),
            'prof': ProfileDetector()
        }

    def detect(self, detector, image_data):
        detector = self.detectors[detector]
        if detector is None:
            return None

        image = Image.create_from_buffer(image_data)
        image.grayscale()
        return detector.detect(image)



#!/usr/bin/python
# -*- coding: utf-8 -*-

# thumbor imaging service
# https://github.com/globocom/thumbor/wiki

# Licensed under the MIT license: 
# http://www.opensource.org/licenses/mit-license
# Copyright (c) 2011 globo.com timehome@corp.globo.com

from remotecv.detectors import CascadeLoaderDetector
from remotecv.detectors.face_detector import FaceDetector
from remotecv.detectors.feature_detector import FeatureDetector

class CompleteDetector(CascadeLoaderDetector):

    def detect(self, image):
        face_detector = FaceDetector()
        feature_detector = FeatureDetector()

        feature_points = []
        face_points = face_detector.detect(image)
        if not face_points:
            face_points = []
            feature_points = feature_detector.detect(image)

        return face_points + feature_points



import json

from remotecv.utils import logger

class ResultStore:

    def __init__(self, redis):
        self.storage = redis

    def to_dict(self, points):
        result = {
            'x': points[0] + (int(points[2]) / 2),
            'y': points[1] + (int(points[3]) / 2),
            'height': int(points[2]),
            'width': int(points[3]),
            'origin': ''
        }
        result['z'] = result['width'] * result['height']
        return result

    def store(self, key, points):
        points_map = [self.to_dict(point) for point in points]
        logger.debug("Points found: %s" % str(points_map))
        self.storage.set("thumbor-detector-%s" % key, json.dumps(points_map))
